@@ -1,6 +1,7 @@
 from pathlib import Path
 from typing import Optional, Union
 
+import lnschema_core
 import sqlmodel as sqm
 from cloudpathlib import CloudPath
 from lamin_logger import logger
@@ -20,6 +21,18 @@ from ._settings_save import save_instance_settings
 from ._settings_store import settings_dir
 
 
+def configure_schema_wetlab(schema_modules):
+    if "retro" in schema_modules:
+        file_loc = lnschema_core.__file__.replace("core", "wetlab")
+        with open(file_loc, "r") as f:
+            content = f.read()
+        with open(file_loc, "w") as f:
+            content = content.replace(
+                '_tables = ["biosample", "techsample"]', "_tables = []"
+            )
+            f.write(content)
+
+
 def setup_instance_db():
     """Setup database.
 
@@ -27,20 +40,17 @@ def setup_instance_db():
     - Database creation.
     - Sign-up and/or log-in.
     """
-    instance_settings = load_or_create_instance_settings()
+    isettings = load_or_create_instance_settings()
     user_settings = load_or_create_user_settings()
-    if instance_settings.storage_dir is None:
+    if isettings.storage_dir is None:
         logger.warning("Instance is not configured. Call `lndb init` or `lndb load`.")
         return None
-    instance_name = instance_settings.name
-    sqlite_file = instance_settings._sqlite_file
-    schema_modules = instance_settings.schema_modules
+    schema_modules = isettings.schema_modules
 
-    if sqlite_file.exists():
-        logger.info(f"Using instance: {sqlite_file}")
-        import lnschema_core  # noqa
+    if isettings._sqlite_file.exists():
+        logger.info(f"Using instance: {isettings._sqlite_file}")
 
-        with sqm.Session(instance_settings.db_engine()) as session:
+        with sqm.Session(isettings.db_engine()) as session:
             version_table = session.exec(sqm.select(lnschema_core.version_yvzi)).all()
 
         versions = [row.v for row in version_table]
@@ -48,26 +58,31 @@ def setup_instance_db():
         current_version = lnschema_core.__version__
 
         if current_version not in versions:
-            logger.info(
-                f"Did you already migrate to core schema module v{current_version}?"
-            )
-            logger.info(
-                f"If yes, run `lndb_setup._db.insert.version_yvzi({current_version},"
-                " db.settings.user.id)`"
-            )
-            logger.warning(
-                "If no, either migrate your instance db schema to version"
-                f" {current_version}.\nOr install the latest version {versions}."
+            logger.error(
+                f"Your database does not seem up-to-date with installed core schema module v{current_version}.\n"  # noqa
+                f"If you already migrated, run `lndb_setup._db.insert.version_yvzi({current_version}, db.settings.user.id)`\n"  # noqa
+                f"If not, migrate to core schema version {current_version} or install {versions}."  # noqa
             )
+            return None
     else:
+        if isettings.cloud_storage and isettings._sqlite_file_local.exists():
+            logger.error(
+                "Your cached local SQLite file still exists, while your cloud SQLite"
+                " file was deleted.\nPlease delete"
+                f" {isettings._sqlite_file_local} or add it to the cloud"
+                " location."
+            )
+            return None
+
         msg = "Loading schema modules: core"
-        import lnschema_core  # noqa
 
         if schema_modules is not None and "bionty" in schema_modules:
             import lnschema_bionty  # noqa
 
             msg += ", bionty"
         if schema_modules is not None and "wetlab" in schema_modules:
+            configure_schema_wetlab(schema_modules)
+
             import lnschema_wetlab  # noqa
 
             msg += ", wetlab"
@@ -75,22 +90,25 @@ def setup_instance_db():
             import lnbfx.schema  # noqa
 
             msg += ", bfx"
+
+        if schema_modules is not None and "retro" in schema_modules:
+            import lnschema_retro  # noqa
+
+            msg += ", retro"
         logger.info(f"{msg}.")
-        SQLModel.metadata.create_all(instance_settings.db_engine())
-        instance_settings._update_cloud_sqlite_file()
+        SQLModel.metadata.create_all(isettings.db_engine())
+        isettings._update_cloud_sqlite_file()
         insert.version_yvzi(lnschema_core.__version__, user_settings.id)
         logger.info(
-            f"Created instance {instance_name} with core schema"
-            f" v{lnschema_core.__version__}: {sqlite_file}"
+            f"Created instance {isettings.name} with core schema"
+            f" v{lnschema_core.__version__}: {isettings._sqlite_file}"
         )
 
     insert_if_not_exists.user(
         user_settings.email, user_settings.id, user_settings.handle
     )
 
-    insert_if_not_exists.storage(
-        instance_settings.storage_dir, instance_settings.storage_region
-    )
+    insert_if_not_exists.storage(isettings.storage_dir, isettings.storage_region)
 
 
 def load(instance_name: str):
@@ -147,7 +165,7 @@ def init(
 
     # setup schema
     if schema is not None:
-        known_modules = ["bionty", "wetlab", "bfx"]
+        known_modules = ["bionty", "wetlab", "bfx", "retro"]
         validated_schema = []
         for module in known_modules:
             if module in schema:
@@ -155,6 +173,7 @@ def init(
         if len(validated_schema) == 0:
             raise RuntimeError(f"Unknown schema modules. Only know {known_modules}.")
         instance_settings.schema_modules = ", ".join(validated_schema)
+
     save_instance_settings(instance_settings)
 
     setup_instance_db()
